A list of the 128 instruments in the General MIDI spec, in order.
Each instrument is represented as a vector where the first item is the "official"/preferred name to be used in the Alda instrument list, and is followed by recognized aliases.
A list of the 128 instruments in the General MIDI spec, in order. Each instrument is represented as a vector where the first item is the "official"/preferred name to be used in the Alda instrument list, and is followed by recognized aliases.
There is only one percussion instrument: midi-percussion
This is a definition of that instrument that has the same shape as
non-percussion-instruments.
There is only one percussion instrument: midi-percussion This is a definition of that instrument that has the same shape as `non-percussion-instruments`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |